@@ -130,7 +130,7 @@ def draw_line(s1, s2, sv, title, file_path, limit=point_limit):
     plt.savefig(file_path)
     # plt.show()
     
-def foo(ohlcvs, path):
+def foo(ohlcvs, symbol, path):
     if ohlcvs is None: 
         return None
     closes = [(datetime.fromtimestamp(i[0]/1000).strftime('%m%d %H'), i[4]) for i in ohlcvs]
